JBoss Tools SVN: r40682 - in trunk: common/features/org.jboss.tools.common.mylyn.feature and 1 other directories.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-01 11:35:49 -0400 (Tue, 01 May 2012)
New Revision: 40682
Modified:
trunk/central/plugins/org.jboss.tools.central.discovery/plugin.xml
trunk/common/features/org.jboss.tools.common.mylyn.feature/feature.xml
trunk/ws/features/org.jboss.tools.ws.test.feature/feature.xml
Log:
JBDS-2089 add mylyn and atlassian deps to org.jboss.tools.common.mylyn.feature; add org.jboss.tools.common.mylyn.feature to JBT Central Discovery
Modified: trunk/central/plugins/org.jboss.tools.central.discovery/plugin.xml
===================================================================
--- trunk/central/plugins/org.jboss.tools.central.discovery/plugin.xml 2012-05-01 14:47:49 UTC (rev 40681)
+++ trunk/central/plugins/org.jboss.tools.central.discovery/plugin.xml 2012-05-01 15:35:49 UTC (rev 40682)
@@ -334,6 +334,33 @@
<connectorDescriptor
categoryId="org.jboss.tools.central.discovery.testing"
groupId="org.jboss.tools.central.discovery.testing.local"
+ description="Mylyn support for reporting JBoss JIRAs and Red Hat Bugzillas"
+ id="org.jboss.tools.common.mylyn.feature"
+ kind="task"
+ license="Free, EPL"
+ name="Mylyn Issue Tracker Connectors"
+ provider="JBoss by Red Hat"
+ siteUrl="http://download.jboss.org/jbosstools/updates/development/indigo/">
+ <iu id="org.jboss.tools.common.mylyn.feature"/>
+ <iu id="org.eclipse.mylyn_feature"/>
+ <iu id="org.eclipse.mylyn.ide_feature"/>
+ <iu id="org.eclipse.mylyn.commons"/>
+ <iu id="org.eclipse.mylyn.context_feature"/>
+ <iu id="org.eclipse.mylyn.bugzilla_feature"/>
+ <iu id="org.eclipse.mylyn.java_feature"/>
+ <iu id="org.eclipse.mylyn.pde_feature"/>
+ <iu id="org.eclipse.mylyn.team_feature"/>
+ <iu id="org.eclipse.mylyn.versions"/>
+ <icon
+ image32="images/jbosstools_icon32.png">
+ </icon>
+ <overview
+ url="http://www.jboss.org/tools">
+ </overview>
+ </connectorDescriptor>
+ <connectorDescriptor
+ categoryId="org.jboss.tools.central.discovery.testing"
+ groupId="org.jboss.tools.central.discovery.testing.local"
description="Tool support for PMD"
id="net.sourceforge.pmd.eclipse"
kind="task"
@@ -341,7 +368,7 @@
name="PMD"
provider="PMD Developers"
siteUrl="http://download.jboss.org/jbosstools/updates/indigo/extras/">
- <iu id="net.sourceforge.pmd.eclipse"/>
+ <iu id="net.sourceforge.pmd.eclipse"/>
<icon
image32="images/pmd_32.png">
</icon>
Modified: trunk/common/features/org.jboss.tools.common.mylyn.feature/feature.xml
===================================================================
--- trunk/common/features/org.jboss.tools.common.mylyn.feature/feature.xml 2012-05-01 14:47:49 UTC (rev 40681)
+++ trunk/common/features/org.jboss.tools.common.mylyn.feature/feature.xml 2012-05-01 15:35:49 UTC (rev 40682)
@@ -6,4 +6,78 @@
<license>%license</license>
<plugin id="org.jboss.tools.common.mylyn" download-size="0" install-size="0" version="0.0.0" />
+
+ <!-- JBDS-2098 add required mylyn and atlassian plugins/features; not sure if we need bamboo, crucible, or fisheye support -->
+ <requires>
+ <import feature="org.eclipse.mylyn_feature" version="3.6.2" match="greaterOrEqual" />
+ <import feature="org.eclipse.mylyn.ide_feature" version="3.6.2" match="greaterOrEqual" />
+ <import feature="org.eclipse.mylyn.commons" version="3.6.2" match="greaterOrEqual" />
+ <import feature="org.eclipse.mylyn.context_feature" version="3.6.2" match="greaterOrEqual" />
+ <import feature="org.eclipse.mylyn.bugzilla_feature" version="3.6.2" match="greaterOrEqual" />
+ <import feature="org.eclipse.mylyn.java_feature" version="3.6.2" match="greaterOrEqual" />
+ <import feature="org.eclipse.mylyn.pde_feature" version="3.6.2" match="greaterOrEqual" />
+ <import feature="org.eclipse.mylyn.team_feature" version="3.6.2" match="greaterOrEqual" />
+ <import feature="org.eclipse.mylyn.versions" version="0.8.2" match="greaterOrEqual" />
+
+ <plugin id="org.eclipse.mylyn.tasks.ui" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.mylyn.tasks.core" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.mylyn.tasks.bugs" version="0.0.0" match="greaterOrEqual"/>
+
+ <plugin id="com.atlassian.connector.commons" version="0.0.0" match="greaterOrEqual"/>
+ <!-- <plugin id="com.atlassian.connector.eclipse.bamboo.core" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.bamboo.ui" version="0.0.0" match="greaterOrEqual"/> -->
+ <plugin id="com.atlassian.connector.eclipse.branding.ui" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.commons.core" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.commons.ui" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.core" version="0.0.0" match="greaterOrEqual"/>
+ <!-- <plugin id="com.atlassian.connector.eclipse.crucible.core" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.crucible.ui" version="0.0.0" match="greaterOrEqual"/> -->
+ <plugin id="com.atlassian.connector.eclipse.cvs.core" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.cvs.ui" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.directclickthrough.ui" version="0.0.0" match="greaterOrEqual"/>
+ <!-- <plugin id="com.atlassian.connector.eclipse.fisheye.core" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.fisheye.ui" version="0.0.0" match="greaterOrEqual"/> -->
+ <plugin id="com.atlassian.connector.eclipse.help" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.jira.core" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.jira.ui" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.monitor.core" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.monitor.ui" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="com.atlassian.connector.eclipse.ui" version="0.0.0" match="greaterOrEqual"/>
+
+ <!-- JBDS-1682 dependent 3rd party plugins needed to install Atlassian JIRA support -->
+ <plugin id="com.thoughtworks.xstream" version="1.3.0" match="greaterOrEqual"/>
+
+ <plugin id="org.eclipse.ui" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.core.runtime" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.core.resources" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.ui.ide" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.ui.workbench.texteditor" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.jface.text" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.osgi" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.core.filesystem" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.ui.forms" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.ui.editors" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.team.core" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.team.ui" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.jface" version="0.0.0" match="greaterOrEqual"/>
+ <plugin id="org.eclipse.compare" version="0.0.0" match="greaterOrEqual"/>
+
+ <plugin id="org.apache.axis" version="1.4.0" match="greaterOrEqual"/>
+ <plugin id="org.apache.commons.logging" version="1.1.1" match="greaterOrEqual"/>
+ <plugin id="org.apache.commons.io" version="2.0.1" match="greaterOrEqual"/>
+ <plugin id="org.apache.commons.httpclient" version="3.1.0" match="greaterOrEqual"/>
+ <plugin id="org.apache.commons.lang" version="2.4.0" match="greaterOrEqual"/>
+ <plugin id="org.apache.commons.codec" version="1.3.0" match="greaterOrEqual"/>
+
+ <plugin id="org.jdom_jaxen" version="1.0.0" match="greaterOrEqual"/>
+ <plugin id="org.mortbay.jetty.server" version="6.1.23" match="greaterOrEqual"/>
+ <plugin id="org.mortbay.jetty.util" version="6.1.23" match="greaterOrEqual"/>
+ <plugin id="org.apache.jasper" version="5.5.17" match="greaterOrEqual"/>
+ <plugin id="org.joda.time" version="1.6.0" match="greaterOrEqual"/>
+
+ <plugin id="javax.servlet" version="3.0.0" match="greaterOrEqual"/>
+ <plugin id="javax.servlet.jsp" version="2.2.0" match="greaterOrEqual"/>
+ <plugin id="javax.xml.rpc" version="1.1.0" match="greaterOrEqual"/>
+ <plugin id="javax.el" version="2.2.0" match="greaterOrEqual"/>
+ </requires>
</feature>
Modified: trunk/ws/features/org.jboss.tools.ws.test.feature/feature.xml
===================================================================
--- trunk/ws/features/org.jboss.tools.ws.test.feature/feature.xml 2012-05-01 14:47:49 UTC (rev 40681)
+++ trunk/ws/features/org.jboss.tools.ws.test.feature/feature.xml 2012-05-01 15:35:49 UTC (rev 40682)
@@ -13,6 +13,14 @@
%license
</license>
+ <requires>
+ <import feature="org.eclipse.jst.enterprise_ui.feature" version="3.3.2" match="compatible"/>
+ <import feature="org.eclipse.jst.web_ui.feature" version="3.3.2" match="compatible"/>
+ <import feature="org.eclipse.wst.web_ui.feature" version="3.3.2" match="compatible"/>
+ <import feature="org.eclipse.wst.ws_ui.feature" version="3.3.2" match="compatible"/>
+ <import feature="org.eclipse.wst.xml_ui.feature" version="3.3.2" match="compatible"/>
+ </requires>
+
<plugin id="org.jboss.tools.ws.core.test" download-size="0" install-size="0" version="0.0.0" />
<plugin id="org.jboss.tools.ws.creation.core.test" download-size="0" install-size="0" version="0.0.0" />
<plugin id="org.jboss.tools.ws.jaxrs.core.test" download-size="0" install-size="0" version="0.0.0" />
12 years, 8 months
JBoss Tools SVN: r40681 - branches/jbosstools-3.3.0.Beta3/central/plugins/org.jboss.tools.central.discovery.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-01 10:47:49 -0400 (Tue, 01 May 2012)
New Revision: 40681
Modified:
branches/jbosstools-3.3.0.Beta3/central/plugins/org.jboss.tools.central.discovery/plugin.xml
Log:
apply patch to add m2e-apt to JBT Central in 33x branch
Modified: branches/jbosstools-3.3.0.Beta3/central/plugins/org.jboss.tools.central.discovery/plugin.xml
===================================================================
--- branches/jbosstools-3.3.0.Beta3/central/plugins/org.jboss.tools.central.discovery/plugin.xml 2012-05-01 14:47:37 UTC (rev 40680)
+++ branches/jbosstools-3.3.0.Beta3/central/plugins/org.jboss.tools.central.discovery/plugin.xml 2012-05-01 14:47:49 UTC (rev 40681)
@@ -198,6 +198,24 @@
<connectorDescriptor
categoryId="org.jboss.tools.central.discovery.maven"
groupId="org.jboss.tools.central.discovery.maven.upstream"
+ description="Maven Integration for Eclipse JDT APT (m2e-apt)"
+ id="org.jboss.tools.maven.apt.feature"
+ kind="task"
+ license="Free, EPL"
+ name="Maven Integration for Eclipse JDT APT (m2e-apt)"
+ provider="JBoss by Red Hat"
+ siteUrl="http://download.jboss.org/jbosstools/updates/indigo/">
+ <iu id="org.jboss.tools.maven.apt.feature"/>
+ <icon
+ image32="images/m2e_32.gif">
+ </icon>
+ <overview
+ url="http://www.eclipse.org/m2e/">
+ </overview>
+ </connectorDescriptor>
+ <connectorDescriptor
+ categoryId="org.jboss.tools.central.discovery.maven"
+ groupId="org.jboss.tools.central.discovery.maven.upstream"
description="Maven Integration for Web Tools (m2e-wtp)"
id="org.maven.ide.eclipse.wtp.feature"
kind="task"
12 years, 8 months
JBoss Tools SVN: r40680 - branches/jbosstools-3.3.0.Beta3/build/aggregate.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-01 10:47:37 -0400 (Tue, 01 May 2012)
New Revision: 40680
Modified:
branches/jbosstools-3.3.0.Beta3/build/aggregate/pom.xml
Log:
remove ref to deprecated site
Modified: branches/jbosstools-3.3.0.Beta3/build/aggregate/pom.xml
===================================================================
--- branches/jbosstools-3.3.0.Beta3/build/aggregate/pom.xml 2012-05-01 14:47:26 UTC (rev 40679)
+++ branches/jbosstools-3.3.0.Beta3/build/aggregate/pom.xml 2012-05-01 14:47:37 UTC (rev 40680)
@@ -20,7 +20,6 @@
mvn clean install -f site/pom.xml -Dcollect.zips.skip
mvn clean install -f soa-site/pom.xml -Dcollect.zips.skip
mvn clean install -f webtools-site/pom.xml
- mvn clean install -f bottests-site/pom.xml
mvn clean install -f coretests-site/pom.xml
mvn clean install -f soatests-site/pom.xml
...
12 years, 8 months
JBoss Tools SVN: r40679 - branches/jbosstools-3.3.0.Beta3/build/aggregate/site.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-05-01 10:47:26 -0400 (Tue, 01 May 2012)
New Revision: 40679
Modified:
branches/jbosstools-3.3.0.Beta3/build/aggregate/site/site.xml
Log:
remove line breaks from category descriptions (JBIDE-11644)
Modified: branches/jbosstools-3.3.0.Beta3/build/aggregate/site/site.xml
===================================================================
--- branches/jbosstools-3.3.0.Beta3/build/aggregate/site/site.xml 2012-05-01 14:26:20 UTC (rev 40678)
+++ branches/jbosstools-3.3.0.Beta3/build/aggregate/site/site.xml 2012-05-01 14:47:26 UTC (rev 40679)
@@ -402,18 +402,11 @@
<!-- CATEGORIES -->
<!-- ########## -->
<category-def name="AbridgedTools" label="Abridged JBoss Tools 3.3">
- <description>Contains most of the JBoss Tools features.
- Excluded are those related to integration with 3rd party
- plugins. Selecting this category will give you all tools
- needed for Web and Seam Development.
- </description>
+ <description>Contains most of the JBoss Tools features. Excluded are those related to integration with 3rd party plugins. Selecting this category will give you all tools needed for Web and Seam Development.</description>
</category-def>
<category-def name="WebTools" label="JBoss Web and Java EE Development">
- <description>Tools to help create web and enterprise applications,
- using JSF, Facelets,
- Seam, Hibernate/JPA, CSS, Webservices and more.
- </description>
+ <description>Tools to help create web and enterprise applications, using JSF, Facelets, Seam, Hibernate/JPA, CSS, Webservices and more.</description>
</category-def>
<category-def name="GeneralTools" label="JBoss Application Development">
@@ -425,22 +418,18 @@
</category-def>
<category-def name="MavenTools" label="JBoss Maven Support">
- <description>Plugins related to Maven and m2eclipse support. Use these
- to enable use of Maven.</description>
+ <description>Plugins related to Maven and m2eclipse support. Use these to enable use of Maven.</description>
</category-def>
<category-def name="CloudTools" label="JBoss Cloud Development Tools">
- <description>Tools for Cloud Development.
- </description>
+ <description>Tools for Cloud Development.</description>
</category-def>
<!-- Only in JBT -->
<category-def name="ReportTools" label="JBoss Business Intelligence, Reporting and Charting">
- <description>Business Intelligence, Reporting and Charting. Use these
- if you plan to integrate Hibernate or Seam with Eclipse BIRT.
- </description>
+ <description>Business Intelligence, Reporting and Charting. Use these if you plan to integrate Hibernate or Seam with Eclipse BIRT.</description>
</category-def>
<category-def name="AllSources" label="Sources">
- <description>Source code for JBoss Tools features</description>
+ <description>Source code for JBoss Tools features.</description>
</category-def>
</site>
12 years, 8 months
JBoss Tools SVN: r40678 - trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test.
by jbosstools-commits@lists.jboss.org
Author: jjankovi
Date: 2012-05-01 10:26:20 -0400 (Tue, 01 May 2012)
New Revision: 40678
Modified:
trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/WSAllBotTests.java
Log:
new test MatrixParamSupportTest included in WSAllBotTests
Modified: trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/WSAllBotTests.java
===================================================================
--- trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/WSAllBotTests.java 2012-05-01 14:25:43 UTC (rev 40677)
+++ trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/WSAllBotTests.java 2012-05-01 14:26:20 UTC (rev 40678)
@@ -13,6 +13,7 @@
import org.jboss.tools.ui.bot.ext.RequirementAwareSuite;
import org.jboss.tools.ws.ui.bot.test.annotation.AnnotationPropertiesTest;
import org.jboss.tools.ws.ui.bot.test.rest.DefaultValueParamSupportTest;
+import org.jboss.tools.ws.ui.bot.test.rest.MatrixParamSupportTest;
import org.jboss.tools.ws.ui.bot.test.rest.PathAnnotationSupportTest;
import org.jboss.tools.ws.ui.bot.test.rest.QueryParamSupportTest;
import org.jboss.tools.ws.ui.bot.test.rest.completion.RESTfulCompletionTest;
@@ -62,6 +63,7 @@
PathAnnotationSupportTest.class,
QueryParamSupportTest.class,
DefaultValueParamSupportTest.class,
+ MatrixParamSupportTest.class,
RESTfulValidationTest.class,
RESTfulCompletionTest.class,
ApplicationPathParameterTest.class,
12 years, 8 months
JBoss Tools SVN: r40677 - trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/rest.
by jbosstools-commits@lists.jboss.org
Author: jjankovi
Date: 2012-05-01 10:25:43 -0400 (Tue, 01 May 2012)
New Revision: 40677
Modified:
trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/rest/QueryParamSupportTest.java
Log:
common local parameters moved to be private global parameters
Modified: trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/rest/QueryParamSupportTest.java
===================================================================
--- trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/rest/QueryParamSupportTest.java 2012-05-01 14:24:09 UTC (rev 40676)
+++ trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/rest/QueryParamSupportTest.java 2012-05-01 14:25:43 UTC (rev 40677)
@@ -19,13 +19,20 @@
public class QueryParamSupportTest extends RESTfulTestBase {
private RESTFullExplorerWizard restfulWizard = null;
-
private String projectName = "restEmpty";
-
private final String QUERY_ONE_PARAM_RESOURCE = "/resources/restful/QueryOneParam.java.ws";
-
private final String QUERY_TWO_PARAM_RESOURCE = "/resources/restful/QueryTwoParam.java.ws";
+ private String queryParam1 = "param1";
+ private String queryParam2 = "param2";
+ private String queryType = "java.lang.String";
+ private String queryParam1New = "newParam1";
+ private String queryParam2New = "newParam2";
+ private String queryType1 = "java.lang.String";
+ private String queryType2 = "java.lang.Integer";
+ private String queryTypeNew = "java.lang.Long";
+
+
@Override
protected String getWsProjectName() {
return projectName;
@@ -39,10 +46,6 @@
@Test
public void testSupportInExplorer() {
- String queryParam1 = "param1";
- String queryParam2 = "param2";
- String queryType = "java.lang.String";
-
prepareWSResource(QUERY_ONE_PARAM_RESOURCE,
getWsPackage(), getWsName(), queryParam1, queryType);
@@ -71,12 +74,6 @@
@Test
public void testEditingQueryParam() {
- String queryParam1 = "param1";
- String queryParam1New = "newParam1";
- String queryParam2 = "param2";
- String queryParam2New = "newParam2";
- String queryType = "java.lang.String";
-
prepareWSResource(QUERY_TWO_PARAM_RESOURCE, getWsPackage(), getWsName(),
queryParam1, queryType, queryParam2, queryType);
@@ -111,14 +108,8 @@
}
@Test
- public void testEditingTypeOfParam() {
+ public void testEditingTypeOfQueryParam() {
- String queryParam1 = "param1";
- String queryParam2 = "param2";
- String queryType1 = "java.lang.String";
- String queryType2 = "java.lang.Integer";
- String queryTypeNew = "java.lang.Long";
-
prepareWSResource(QUERY_TWO_PARAM_RESOURCE, getWsPackage(), getWsName(),
queryParam1, queryType1, queryParam2, queryType2);
12 years, 8 months
JBoss Tools SVN: r40676 - trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/rest.
by jbosstools-commits@lists.jboss.org
Author: jjankovi
Date: 2012-05-01 10:24:09 -0400 (Tue, 01 May 2012)
New Revision: 40676
Added:
trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/rest/MatrixParamSupportTest.java
Log:
new test MatrixParamSupportTest implemented
Added: trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/rest/MatrixParamSupportTest.java
===================================================================
--- trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/rest/MatrixParamSupportTest.java (rev 0)
+++ trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/src/org/jboss/tools/ws/ui/bot/test/rest/MatrixParamSupportTest.java 2012-05-01 14:24:09 UTC (rev 40676)
@@ -0,0 +1,142 @@
+/*******************************************************************************
+ * Copyright (c) 2007-2012 Red Hat, Inc.
+ * Distributed under license by Red Hat, Inc. All rights reserved.
+ * This program is made available under the terms of the
+ * Eclipse Public License v1.0 which accompanies this distribution,
+ * and is available at http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributor:
+ * Red Hat, Inc. - initial API and implementation
+ ******************************************************************************/
+
+package org.jboss.tools.ws.ui.bot.test.rest;
+
+import org.eclipse.swtbot.swt.finder.widgets.SWTBotTreeItem;
+import org.jboss.tools.ui.bot.ext.Timing;
+import org.jboss.tools.ws.ui.bot.test.ti.wizard.RESTFullExplorerWizard;
+import org.junit.Test;
+
+public class MatrixParamSupportTest extends RESTfulTestBase {
+
+ private RESTFullExplorerWizard restfulWizard = null;
+ private String projectName = "restEmpty";
+ private final String MATRIX_PARAM_RESOURCE = "/resources/restful/MatrixParam.java.ws";
+
+ private String matrixParam1 = "author";
+ private String matrixParam2 = "country";
+ private String matrixParamNew = "library";
+ private String matrixParamType1 = "java.lang.String";
+ private String matrixParamType2 = "java.lang.Integer";
+ private String matrixParamTypeNew = "java.lang.Long";
+
+ @Override
+ protected String getWsProjectName() {
+ return projectName;
+ }
+
+ @Override
+ public void cleanup() {
+ bot.activeEditor().toTextEditor().save();
+ }
+
+ @Test
+ public void testMatrixParamSupport() {
+
+ prepareWSResource(MATRIX_PARAM_RESOURCE, getWsPackage(), getWsName(),
+ matrixParam1, matrixParamType1, matrixParam2, matrixParamType2);
+
+ restfulWizard = new RESTFullExplorerWizard(getWsProjectName());
+ SWTBotTreeItem[] restServices = restfulWizard.getAllRestServices();
+
+ assertTrue("There should be one RESTful web service instead of "
+ + restServices.length, restServices.length == 1);
+ String path = restfulWizard.getPathForRestFulService(restServices[0]);
+ assertEquals("/rest;" + matrixParam1 + "={" + matrixParamType1 + "};"
+ + matrixParam2 + "={" + matrixParamType2 + "}", path);
+
+ }
+
+ @Test
+ public void testEditingMatrixParam() {
+
+ prepareWSResource(MATRIX_PARAM_RESOURCE, getWsPackage(), getWsName(),
+ matrixParam1, matrixParamType1, matrixParam2, matrixParamType2);
+
+ resourceHelper.replaceInEditor(bot.activeEditor().toTextEditor(),
+ matrixParam1, matrixParamNew, false);
+ bot.sleep(Timing.time2S());
+
+ restfulWizard = new RESTFullExplorerWizard(getWsProjectName());
+ SWTBotTreeItem[] restServices = restfulWizard.getAllRestServices();
+
+ assertTrue("There should be one RESTful web service instead of "
+ + restServices.length, restServices.length == 1);
+ String path = restfulWizard.getPathForRestFulService(restServices[0]);
+ assertEquals("/rest;" + matrixParamNew + "={" + matrixParamType1 + "};"
+ + matrixParam2 + "={" + matrixParamType2 + "}", path);
+
+ resourceHelper.replaceInEditor(bot.activeEditor().toTextEditor(),
+ matrixParamNew, matrixParam1, false);
+ resourceHelper.replaceInEditor(bot.activeEditor().toTextEditor(),
+ matrixParam2, matrixParamNew, false);
+ bot.sleep(Timing.time2S());
+ restfulWizard = new RESTFullExplorerWizard(getWsProjectName());
+ restServices = restfulWizard.getAllRestServices();
+
+ assertTrue("There should be one RESTful web service instead of "
+ + restServices.length, restServices.length == 1);
+ path = restfulWizard.getPathForRestFulService(restServices[0]);
+ assertEquals("/rest;" + matrixParam1 + "={" + matrixParamType1 + "};"
+ + matrixParamNew + "={" + matrixParamType2 + "}", path);
+
+ }
+
+ @Test
+ public void testEditingTypeOfMatrixParam() {
+
+ prepareWSResource(MATRIX_PARAM_RESOURCE, getWsPackage(), getWsName(),
+ matrixParam1, matrixParamType1, matrixParam2, matrixParamType2);
+
+ resourceHelper.replaceInEditor(bot.activeEditor().toTextEditor(),
+ matrixParamType1, matrixParamTypeNew, false);
+ bot.sleep(Timing.time2S());
+
+ restfulWizard = new RESTFullExplorerWizard(getWsProjectName());
+ SWTBotTreeItem[] restServices = restfulWizard.getAllRestServices();
+
+ assertTrue("There should be one RESTful web service instead of " +
+ restServices.length, restServices.length == 1);
+ String path = restfulWizard.getPathForRestFulService(restServices[0]);
+ assertEquals("/rest;" + matrixParam1 + "={" + matrixParamTypeNew + "};"
+ + matrixParam2 + "={" + matrixParamType2 + "}", path);
+
+
+ resourceHelper.replaceInEditor(bot.activeEditor().toTextEditor(),
+ matrixParamTypeNew, matrixParamType1, false);
+ resourceHelper.replaceInEditor(bot.activeEditor().toTextEditor(),
+ matrixParamType2, matrixParamTypeNew, false);
+ bot.sleep(Timing.time2S());
+ restfulWizard = new RESTFullExplorerWizard(getWsProjectName());
+ restServices = restfulWizard.getAllRestServices();
+
+ assertTrue("There should be one RESTful web service instead of " +
+ restServices.length, restServices.length == 1);
+ path = restfulWizard.getPathForRestFulService(restServices[0]);
+ assertEquals("/rest;" + matrixParam1 + "={" + matrixParamType1 + "};"
+ + matrixParam2 + "={" + matrixParamTypeNew + "}", path);
+
+ }
+
+ private void prepareWSResource(String streamPath, Object... parameters) {
+
+ packageExplorer.openFile(getWsProjectName(), "src", getWsPackage(),
+ getWsName() + ".java").toTextEditor();
+ resourceHelper.copyResourceToClassWithSave(
+ bot.editorByTitle(getWsName() + ".java"),
+ QueryParamSupportTest.class.getResourceAsStream(streamPath),
+ false, false, parameters);
+ bot.sleep(Timing.time2S());
+
+ }
+
+}
12 years, 8 months
JBoss Tools SVN: r40675 - trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/resources/restful.
by jbosstools-commits@lists.jboss.org
Author: jjankovi
Date: 2012-05-01 10:23:45 -0400 (Tue, 01 May 2012)
New Revision: 40675
Added:
trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/resources/restful/MatrixParam.java.ws
Log:
resource file for new MatrixParamSupportTest added
Added: trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/resources/restful/MatrixParam.java.ws
===================================================================
--- trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/resources/restful/MatrixParam.java.ws (rev 0)
+++ trunk/ws/tests/org.jboss.tools.ws.ui.bot.test/resources/restful/MatrixParam.java.ws 2012-05-01 14:23:45 UTC (rev 40675)
@@ -0,0 +1,16 @@
+package {0};
+
+import javax.ws.rs.GET;
+import javax.ws.rs.MatrixParam;
+import javax.ws.rs.Path;
+
+@Path("/rest")
+public class {1} '{'
+
+ @GET
+ public void getBooks(@MatrixParam("{2}") {3} param1,
+ @MatrixParam("{4}") {5} param2) '{'
+
+ '}'
+
+'}'
12 years, 8 months
JBoss Tools SVN: r40674 - in trunk/cdi/tests/org.jboss.tools.cdi.bot.test/src/org/jboss/tools/cdi/bot/test/quickfix: test and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: jjankovi
Date: 2012-05-01 09:46:44 -0400 (Tue, 01 May 2012)
New Revision: 40674
Modified:
trunk/cdi/tests/org.jboss.tools.cdi.bot.test/src/org/jboss/tools/cdi/bot/test/quickfix/base/BeansXMLQuickFixTestBase.java
trunk/cdi/tests/org.jboss.tools.cdi.bot.test/src/org/jboss/tools/cdi/bot/test/quickfix/test/BeansXMLValidationQuickFixTest.java
Log:
trying to eliminate problem with waiting for CDI validator
Modified: trunk/cdi/tests/org.jboss.tools.cdi.bot.test/src/org/jboss/tools/cdi/bot/test/quickfix/base/BeansXMLQuickFixTestBase.java
===================================================================
--- trunk/cdi/tests/org.jboss.tools.cdi.bot.test/src/org/jboss/tools/cdi/bot/test/quickfix/test/BeansXMLValidationQuickFixTest.java 2012-05-01 13:46:11 UTC (rev 40673)
+++ trunk/cdi/tests/org.jboss.tools.cdi.bot.test/src/org/jboss/tools/cdi/bot/test/quickfix/test/BeansXMLValidationQuickFixTest.java 2012-05-01 13:46:44 UTC (rev 40674)
@@ -13,6 +13,7 @@
import org.jboss.tools.cdi.bot.test.annotations.CDIWizardType;
import org.jboss.tools.cdi.bot.test.quickfix.base.BeansXMLQuickFixTestBase;
+import org.jboss.tools.ui.bot.ext.Timing;
import org.junit.Test;
/**
@@ -34,6 +35,8 @@
String bean = "A1";
beansHelper.createBeansXMLWithAlternative(getProjectName(), getPackageName(), bean);
+ waitForCDIValidator();
+
resolveAddNewAlternative(bean, getPackageName());
assertTrue(isBeanXMLValidationErrorEmpty());
@@ -106,4 +109,8 @@
}
+ private void waitForCDIValidator() {
+ bot.sleep(Timing.time3S());
+ }
+
}
12 years, 8 months
JBoss Tools SVN: r40673 - trunk/cdi/tests/org.jboss.tools.cdi.bot.test.
by jbosstools-commits@lists.jboss.org
Author: jjankovi
Date: 2012-05-01 09:46:11 -0400 (Tue, 01 May 2012)
New Revision: 40673
Modified:
trunk/cdi/tests/org.jboss.tools.cdi.bot.test/build.properties
Log:
resource folder is included in bin.includes in build.properties
Modified: trunk/cdi/tests/org.jboss.tools.cdi.bot.test/build.properties
===================================================================
--- trunk/cdi/tests/org.jboss.tools.cdi.bot.test/build.properties 2012-05-01 13:44:45 UTC (rev 40672)
+++ trunk/cdi/tests/org.jboss.tools.cdi.bot.test/build.properties 2012-05-01 13:46:11 UTC (rev 40673)
@@ -1,4 +1,4 @@
source.. = src/
output.. = bin/
bin.includes = META-INF/,\
- .
+ resources/
12 years, 8 months
--- trunk/cdi/tests/org.jboss.tools.cdi.bot.test/src/org/jboss/tools/cdi/bot/test/quickfix/base/BeansXMLQuickFixTestBase.java 2012-05-01 13:46:11 UTC (rev 40673)
+++ trunk/cdi/tests/org.jboss.tools.cdi.bot.test/src/org/jboss/tools/cdi/bot/test/quickfix/base/BeansXMLQuickFixTestBase.java 2012-05-01 13:46:44 UTC (rev 40674)
@@ -31,7 +31,7 @@
/**
* Method firstly gets beans.xml validation problem. Then
* it opens quick fix wizard, selects default value and
* press finish button
*/
private void openBeanXMLValidationProblem(ValidationType validationProblemType) {
@@ -42,7 +42,7 @@
QuickFixDialogWizard qfWizard = new QuickFixDialogWizard();
qfWizard.setFix(qfWizard.getAvailableFixes().get(0));
qfWizard.setResource(qfWizard.getResources().get(0));
- qfWizard.finish();
+ qfWizard.finishWithWait();
}
/**
@@ -56,7 +56,7 @@
/**
* Method resolves validation error where there is no such Alternative as
* configured in beans.xml. It opens quick fix and through finish button
* the Bean Wizard dialog is opened where both parameters are used to create
* the new alternative bean
* @param name
@@ -67,16 +67,16 @@
openBeanXMLValidationProblem(ValidationType.NO_CLASS);
CDIWizardBase cdiWizardBase = new CDIWizardBase(CDIWizardType.BEAN);
if (cdiWizardBase.isAlternative() && cdiWizardBase.canFinish()) {
- cdiWizardBase.setName(name).setPackage(pkg).finish();
+ cdiWizardBase.setName(name).setPackage(pkg).finishWithWait();
}else {
- fail("Dialog can't be finished");
+ fail("Dialog can't be finishWithWaited");
}
}
/**
* Method resolves validation error where there is no such Stereotype as
* configured in beans.xml. It opens quick fix and through finish button
* the Stereotype Wizard dialog is opened where both parameters are used to create
* the new stereotype annotation
* @param name
@@ -87,16 +87,16 @@
openBeanXMLValidationProblem(ValidationType.NO_ANNOTATION);
CDIWizardBase cdiWizardBase = new CDIWizardBase(CDIWizardType.STEREOTYPE);
if (cdiWizardBase.isAlternative() && cdiWizardBase.canFinish()) {
- cdiWizardBase.setName(name).setPackage(pkg).finish();
+ cdiWizardBase.setName(name).setPackage(pkg).finishWithWait();
}else {
- fail("Dialog can't be finished");
+ fail("Dialog can't be finishWithWaited");
}
}
/**
* Method resolves validation error where there is no such decorator as
* configured in beans.xml. It opens quick fix and through finish button
* the Decorator Wizard dialog is opened where both parameters are used to create
* the new decorator. Interface "java.util.List" is automatically used.
* @param name
@@ -108,16 +108,16 @@
CDIWizardBase cdiWizardBase = new CDIWizardBase(CDIWizardType.DECORATOR);
cdiWizardBase.addInterface("java.util.List");
if (cdiWizardBase.canFinish()) {
- cdiWizardBase.setName(name).setPackage(pkg).finish();
+ cdiWizardBase.setName(name).setPackage(pkg).finishWithWait();
} else {
- fail("Dialog can't be finished");
+ fail("Dialog can't be finishWithWaited");
}
}
/**
* Method resolves validation error where there is no such Interceptor as
* configured in beans.xml. It opens quick fix and through finish button
* the Interceptor Wizard dialog is opened where both parameters are used to create
* the new Interceptor
* @param name
@@ -128,9 +128,9 @@
openBeanXMLValidationProblem(ValidationType.NO_CLASS);
CDIWizardBase cdiWizardBase = new CDIWizardBase(CDIWizardType.INTERCEPTOR);
if (cdiWizardBase.canFinish()) {
- cdiWizardBase.setName(name).setPackage(pkg).finish();
+ cdiWizardBase.setName(name).setPackage(pkg).finishWithWait();
}else {
- fail("Dialog can't be finished");
+ fail("Dialog can't be finishWithWaited");
}
}
Modified: trunk/cdi/tests/org.jboss.tools.cdi.bot.test/src/org/jboss/tools/cdi/bot/test/quickfix/test/BeansXMLValidationQuickFixTest.java
@@ -31,7 +31,7 @@
* Method firstly gets beans.xml validation problem. Then
* it opens quick fix wizard, selects default value and
- * press finish button
+ * press finishWithWait button
*/
private void openBeanXMLValidationProblem(ValidationType validationProblemType) {
@@ -56,7 +56,7 @@
/**
* Method resolves validation error where there is no such Alternative as
- * configured in beans.xml. It opens quick fix and through finish button
+ * configured in beans.xml. It opens quick fix and through finishWithWait button
* the Bean Wizard dialog is opened where both parameters are used to create
* the new alternative bean
@@ -67,16 +67,16 @@
/**
* Method resolves validation error where there is no such Stereotype as
- * configured in beans.xml. It opens quick fix and through finish button
+ * configured in beans.xml. It opens quick fix and through finishWithWait button
* the Stereotype Wizard dialog is opened where both parameters are used to create
* the new stereotype annotation
@@ -87,16 +87,16 @@
/**
* Method resolves validation error where there is no such decorator as
- * configured in beans.xml. It opens quick fix and through finish button
+ * configured in beans.xml. It opens quick fix and through finishWithWait button
* the Decorator Wizard dialog is opened where both parameters are used to create
* the new decorator. Interface "java.util.List" is automatically used.
@@ -108,16 +108,16 @@
/**
* Method resolves validation error where there is no such Interceptor as
- * configured in beans.xml. It opens quick fix and through finish button
+ * configured in beans.xml. It opens quick fix and through finishWithWait button
* the Interceptor Wizard dialog is opened where both parameters are used to create
* the new Interceptor
===================================================================